↑ Up

SRASS---0.1.THM-Sol.s

View TPTP
Problem
Process solution in
SystemOnTSTP
Download .tgz
%------------------------------------------------------------------------------
% File     : SRASS---0.1
% Problem  : NUM924+1 : TPTP v5.3.0. Released v5.3.0.
% Transfm  : none
% Format   : tptp
% Command  : SRASS -q2 -a 0 10 10 10 -i3 -n60 %s

% Computer : art06.cs.miami.edu
% Model    : i686 i686
% CPU      : Intel(R) Pentium(R) 4 CPU 2.80GHz @ 2800MHz
% Memory   : 2005MB
% OS       : Linux 2.6.32.26-175.fc12.i686.PAE
% CPULimit : 300s
% DateTime : Sun Dec  4 00:27:57 EST 2011

% Result   : Theorem 1.07s
% Output   : Solution 1.07s
% Verified : 
% SZS Type : None (Parsing solution fails)
% Syntax   : Number of formulae    : 0

% Comments : 
%------------------------------------------------------------------------------
%----ERROR: Could not form TPTP format derivation
%------------------------------------------------------------------------------
%----ORIGINAL SYSTEM OUTPUT
% Reading problem from /tmp/SystemOnTPTP29672/NUM924+1.tptp
% Adding relevance values
% Extracting the conjecture
% Sorting axioms by relevance
% Looking for THM       ... 
% found
% SZS status THM for /tmp/SystemOnTPTP29672/NUM924+1.tptp
% SZS output start Solution for /tmp/SystemOnTPTP29672/NUM924+1.tptp
% TreeLimitedRun: ----------------------------------------------------------
% TreeLimitedRun: /home/graph/tptp/Systems/EP---1.4/eproof_ram --print-statistics -xAuto -tAuto --cpu-limit=60 --memory-limit=Auto --tstp-format /tmp/SRASS.s.p 
% TreeLimitedRun: CPU time limit is 60s
% TreeLimitedRun: WC  time limit is 120s
% TreeLimitedRun: PID is 29786
% TreeLimitedRun: ----------------------------------------------------------
% PrfWatch: 0.00 CPU 0.03 WC
% # Garbage collection reclaimed 29 unused term cells.
% # Garbage collection reclaimed 442 unused term cells.
% # Garbage collection reclaimed 390 unused term cells.
% # Garbage collection reclaimed 320 unused term cells.
% # Garbage collection reclaimed 339 unused term cells.
% # Garbage collection reclaimed 246 unused term cells.
% # Garbage collection reclaimed 200 unused term cells.
% # Garbage collection reclaimed 171 unused term cells.
% # Garbage collection reclaimed 29 unused term cells.
% # Auto-Ordering is analysing problem.
% # Problem is type GHSMNFFMM21MD
% # Auto-mode selected ordering type KBO6
% # Auto-mode selected ordering precedence scheme <invfreq>
% # Auto-mode selected weight ordering scheme <precrank20>
% #
% # Auto-Heuristic is analysing problem.
% # Problem is type GHSMNFFMM21MD
% # Auto-Mode selected heuristic G_E___107_C41_F1_PI_AE_Q4_CS_SP_PS_S0Y
% # and selection function SelectMaxLComplexAvoidPosPred.
% #
% # Initializing proof state
% # Scanning for AC axioms
% # plus_plus_int is AC
% # times_times_int is AC
% # AC handling enabled
% # Presaturation interreduction done
% # Proof found!
% # SZS status Theorem
% # Parsed axioms                      : 107
% # Removed by relevancy pruning       : 0
% # Initial clauses                    : 159
% # Removed in clause preprocessing    : 22
% # Initial clauses in saturation      : 137
% # Processed clauses                  : 137
% # ...of these trivial                : 9
% # ...subsumed                        : 13
% # ...remaining for further processing: 114
% # Other redundant clauses eliminated : 1
% # Clauses deleted for lack of memory : 0
% # Backward-subsumed                  : 0
% # Backward-rewritten                 : 2
% # Generated clauses                  : 1
% # ...of the previous two non-trivial : 2
% # Contextual simplify-reflections    : 1
% # Paramodulations                    : 0
% # Factorizations                     : 0
% # Equation resolutions               : 1
% # Current number of processed clauses: 111
% #    Positive orientable unit clauses: 30
% #    Positive unorientable unit clauses: 3
% #    Negative unit clauses           : 4
% #    Non-unit-clauses                : 74
% # Current number of unprocessed clauses: 2
% # ...number of literals in the above : 2
% # Clause-clause subsumption calls (NU) : 169
% # Rec. Clause-clause subsumption calls : 168
% # Unit Clause-clause subsumption calls : 3
% # Rewrite failures with RHS unbound  : 0
% # Indexed BW rewrite attempts        : 23
% # Indexed BW rewrite successes       : 18
% # Backwards rewriting index :   106 leaves,   1.36+/-0.992 terms/leaf
% # Paramod-from index      :    62 leaves,   1.15+/-0.434 terms/leaf
% # Paramod-into index      :    89 leaves,   1.33+/-0.884 terms/leaf
% # SZS output start CNFRefutation.
% fof(36, axiom,plus_plus_int(power_power_int(s,number_number_of_nat(bit0(bit1(pls)))),one_one_int)=times_times_int(plus_plus_int(times_times_int(number_number_of_int(bit0(bit0(bit1(pls)))),m),one_one_int),t),file('/tmp/SRASS.s.p', fact_3_t)).
% fof(39, axiom,ord_less_int(times_times_int(plus_plus_int(times_times_int(number_number_of_int(bit0(bit0(bit1(pls)))),m),one_one_int),t),times_times_int(plus_plus_int(times_times_int(number_number_of_int(bit0(bit0(bit1(pls)))),m),one_one_int),zero_zero_int)),file('/tmp/SRASS.s.p', fact_2__096_I4_A_K_Am_A_L_A1_J_A_K_At_A_060_A_I4_A_K_Am_A_L_A1_J_A_K_A0_096)).
% fof(46, axiom,zero_zero_int=number_number_of_int(pls),file('/tmp/SRASS.s.p', fact_105_zero__is__num__zero)).
% fof(59, axiom,![X26]:number_number_of_int(X26)=X26,file('/tmp/SRASS.s.p', fact_24_number__of__is__id)).
% fof(60, axiom,![X7]:![X9]:times_times_int(X7,X9)=times_times_int(X9,X7),file('/tmp/SRASS.s.p', fact_25_zmult__commute)).
% fof(72, axiom,![X9]:times_times_int(pls,X9)=pls,file('/tmp/SRASS.s.p', fact_66_mult__Pls)).
% fof(73, axiom,![X26]:![X39]:times_times_int(bit0(X26),X39)=bit0(times_times_int(X26,X39)),file('/tmp/SRASS.s.p', fact_67_mult__Bit0)).
% fof(87, axiom,![X7]:![X9]:plus_plus_int(X7,X9)=plus_plus_int(X9,X7),file('/tmp/SRASS.s.p', fact_104_zadd__commute)).
% fof(107, conjecture,ord_less_int(plus_plus_int(power_power_int(s,number_number_of_nat(bit0(bit1(pls)))),one_one_int),zero_zero_int),file('/tmp/SRASS.s.p', conj_0)).
% fof(108, negated_conjecture,~(ord_less_int(plus_plus_int(power_power_int(s,number_number_of_nat(bit0(bit1(pls)))),one_one_int),zero_zero_int)),inference(assume_negation,[status(cth)],[107])).
% fof(115, negated_conjecture,~(ord_less_int(plus_plus_int(power_power_int(s,number_number_of_nat(bit0(bit1(pls)))),one_one_int),zero_zero_int)),inference(fof_simplification,[status(thm)],[108,theory(equality)])).
% cnf(235,plain,(plus_plus_int(power_power_int(s,number_number_of_nat(bit0(bit1(pls)))),one_one_int)=times_times_int(plus_plus_int(times_times_int(number_number_of_int(bit0(bit0(bit1(pls)))),m),one_one_int),t)),inference(split_conjunct,[status(thm)],[36])).
% cnf(244,plain,(ord_less_int(times_times_int(plus_plus_int(times_times_int(number_number_of_int(bit0(bit0(bit1(pls)))),m),one_one_int),t),times_times_int(plus_plus_int(times_times_int(number_number_of_int(bit0(bit0(bit1(pls)))),m),one_one_int),zero_zero_int))),inference(split_conjunct,[status(thm)],[39])).
% cnf(262,plain,(zero_zero_int=number_number_of_int(pls)),inference(split_conjunct,[status(thm)],[46])).
% fof(295, plain,![X27]:number_number_of_int(X27)=X27,inference(variable_rename,[status(thm)],[59])).
% cnf(296,plain,(number_number_of_int(X1)=X1),inference(split_conjunct,[status(thm)],[295])).
% fof(297, plain,![X10]:![X11]:times_times_int(X10,X11)=times_times_int(X11,X10),inference(variable_rename,[status(thm)],[60])).
% cnf(298,plain,(times_times_int(X1,X2)=times_times_int(X2,X1)),inference(split_conjunct,[status(thm)],[297])).
% fof(326, plain,![X10]:times_times_int(pls,X10)=pls,inference(variable_rename,[status(thm)],[72])).
% cnf(327,plain,(times_times_int(pls,X1)=pls),inference(split_conjunct,[status(thm)],[326])).
% fof(328, plain,![X40]:![X41]:times_times_int(bit0(X40),X41)=bit0(times_times_int(X40,X41)),inference(variable_rename,[status(thm)],[73])).
% cnf(329,plain,(times_times_int(bit0(X1),X2)=bit0(times_times_int(X1,X2))),inference(split_conjunct,[status(thm)],[328])).
% fof(367, plain,![X10]:![X11]:plus_plus_int(X10,X11)=plus_plus_int(X11,X10),inference(variable_rename,[status(thm)],[87])).
% cnf(368,plain,(plus_plus_int(X1,X2)=plus_plus_int(X2,X1)),inference(split_conjunct,[status(thm)],[367])).
% cnf(423,negated_conjecture,(~ord_less_int(plus_plus_int(power_power_int(s,number_number_of_nat(bit0(bit1(pls)))),one_one_int),zero_zero_int)),inference(split_conjunct,[status(thm)],[115])).
% cnf(424,plain,(pls=zero_zero_int),inference(rw,[status(thm)],[262,296,theory(equality)]),['unfolding']).
% cnf(438,plain,(times_times_int(plus_plus_int(times_times_int(bit0(bit0(bit1(pls))),m),one_one_int),t)=plus_plus_int(power_power_int(s,number_number_of_nat(bit0(bit1(pls)))),one_one_int)),inference(rw,[status(thm)],[235,296,theory(equality)]),['unfolding']).
% cnf(440,plain,(ord_less_int(times_times_int(plus_plus_int(times_times_int(bit0(bit0(bit1(pls))),m),one_one_int),t),times_times_int(plus_plus_int(times_times_int(bit0(bit0(bit1(pls))),m),one_one_int),zero_zero_int))),inference(rw,[status(thm)],[inference(rw,[status(thm)],[244,296,theory(equality)]),296,theory(equality)]),['unfolding']).
% cnf(487,negated_conjecture,(~ord_less_int(plus_plus_int(one_one_int,power_power_int(s,number_number_of_nat(bit0(bit1(pls))))),pls)),inference(rw,[status(thm)],[inference(rw,[status(thm)],[423,368,theory(equality)]),424,theory(equality)])).
% cnf(514,plain,(times_times_int(t,plus_plus_int(one_one_int,bit0(bit0(times_times_int(m,bit1(pls))))))=plus_plus_int(power_power_int(s,number_number_of_nat(bit0(bit1(pls)))),one_one_int)),inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[438,329,theory(equality)]),329,theory(equality)]),298,theory(equality)]),368,theory(equality)]),298,theory(equality)])).
% cnf(515,plain,(times_times_int(t,plus_plus_int(one_one_int,bit0(bit0(times_times_int(m,bit1(pls))))))=plus_plus_int(one_one_int,power_power_int(s,number_number_of_nat(bit0(bit1(pls)))))),inference(rw,[status(thm)],[514,368,theory(equality)])).
% cnf(531,plain,(ord_less_int(plus_plus_int(one_one_int,power_power_int(s,number_number_of_nat(bit0(bit1(pls))))),pls)),inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[inference(rw,[status(thm)],[440,329,theory(equality)]),329,theory(equality)]),298,theory(equality)]),368,theory(equality)]),298,theory(equality)]),515,theory(equality)]),329,theory(equality)]),329,theory(equality)]),298,theory(equality)]),368,theory(equality)]),424,theory(equality)]),298,theory(equality)]),327,theory(equality)])).
% cnf(532,plain,($false),inference(sr,[status(thm)],[531,487,theory(equality)])).
% cnf(533,plain,($false),532,['proof']).
% # SZS output end CNFRefutation
% PrfWatch: 0.07 CPU 0.19 WC
% FINAL PrfWatch: 0.07 CPU 0.19 WC
% SZS output end Solution for /tmp/SystemOnTPTP29672/NUM924+1.tptp
% WARNING: TreeLimitedRun lost 0.09s, total lost is 0.09s
% 
%------------------------------------------------------------------------------